class EnvironmentalVariablesEnum:
    PIP_URL = "PIP_URL"
    PIP_KEY = "PIP_KEY"
    PIP_GET_RESULTS = "PIP_GET_RESULTS"
    ENVIRONMENTAL_VARIABLES = "ENVIRONMENTAL_VARIABLES"
    AIZYNTH_PREDICTION_URL = "AIZYNTH_PREDICTION_URL"
    AIZYNTH_BUILDING_BLOCKS_URL = "AIZYNTH_BUILDING_BLOCKS_URL"
    AIZYNTH_TOKEN = "AIZYNTH_TOKEN"
